@@ -4,6 +4,7 @@ import os
 import tempfile
 import unittest
 
+import mkdocs
 from mkdocs import utils
 from mkdocs.config import config_options
 
@@ -124,6 +125,27 @@ class RepoURLTest(unittest.TestCase):
         self.assertEqual(config['repo_url'], config['repo_url'])
         self.assertEqual(config['repo_name'], "Launchpad")
 
+    def test_edit_uri_github(self):
+
+        option = config_options.RepoURL()
+        config = {'repo_url': "https://github.com/mkdocs/mkdocs"}
+        option.post_validation(config, 'repo_url')
+        self.assertEqual(config['edit_uri'], 'edit/master/docs/')
+
+    def test_edit_uri_bitbucket(self):
+
+        option = config_options.RepoURL()
+        config = {'repo_url': "https://bitbucket.org/gutworth/six/"}
+        option.post_validation(config, 'repo_url')
+        self.assertEqual(config['edit_uri'], 'src/default/docs/')
+
+    def test_edit_uri_custom(self):
+
+        option = config_options.RepoURL()
+        config = {'repo_url': "https://launchpad.net/python-tuskarclient"}
+        option.post_validation(config, 'repo_url')
+        self.assertEqual(config.get('edit_uri'), None)
+
 
 class DirTest(unittest.TestCase):
 
@@ -164,14 +186,40 @@ class DirTest(unittest.TestCase):
         self.assertRaises(config_options.ValidationError,
                           option.validate, [])
 
+    def test_doc_dir_is_config_dir(self):
+
+        test_config = {
+            'config_file_path': os.path.join(os.path.abspath('.'), 'mkdocs.yml'),
+            'docs_dir': '.'
+        }
+
+        docs_dir = config_options.Dir()
+
+        test_config['docs_dir'] = docs_dir.validate(test_config['docs_dir'])
+
+        self.assertRaises(config_options.ValidationError,
+                          docs_dir.post_validation, test_config, 'docs_dir')
+
 
 class SiteDirTest(unittest.TestCase):
 
+    def validate_config(self, config):
+        """ Given a config with values for site_dir and doc_dir, run site_dir post_validation. """
+        site_dir = config_options.SiteDir()
+        docs_dir = config_options.Dir()
+
+        config['config_file_path'] = os.path.join(os.path.abspath('..'), 'mkdocs.yml')
+
+        config['docs_dir'] = docs_dir.validate(config['docs_dir'])
+        config['site_dir'] = site_dir.validate(config['site_dir'])
+        site_dir.post_validation(config, 'site_dir')
+        return True  # No errors were raised
+
     def test_doc_dir_in_site_dir(self):
 
         j = os.path.join
-        option = config_options.SiteDir()
-        docs_dir = config_options.Dir()
+        # The parent dir is not the same on every system, so use the actual dir name
+        parent_dir = mkdocs.__file__.split(os.sep)[-3]
 
         test_configs = (
             {'docs_dir': j('site', 'docs'), 'site_dir': 'site'},
@@ -179,16 +227,13 @@ class SiteDirTest(unittest.TestCase):
             {'docs_dir': '.', 'site_dir': '.'},
             {'docs_dir': 'docs', 'site_dir': ''},
             {'docs_dir': '', 'site_dir': ''},
-            {'docs_dir': j('..', 'mkdocs', 'docs'), 'site_dir': 'docs'},
+            {'docs_dir': j('..', parent_dir, 'docs'), 'site_dir': 'docs'},
+            {'docs_dir': 'docs', 'site_dir': '/'}
         )
 
         for test_config in test_configs:
-
-            test_config['docs_dir'] = docs_dir.validate(test_config['docs_dir'])
-            test_config['site_dir'] = option.validate(test_config['site_dir'])
-
             self.assertRaises(config_options.ValidationError,
-                              option.post_validation, test_config, 'key')
+                              self.validate_config, test_config)
 
     def test_site_dir_in_docs_dir(self):
 
@@ -198,21 +243,23 @@ class SiteDirTest(unittest.TestCase):
             {'docs_dir': 'docs', 'site_dir': j('docs', 'site')},
             {'docs_dir': '.', 'site_dir': 'site'},
             {'docs_dir': '', 'site_dir': 'site'},
+            {'docs_dir': '/', 'site_dir': 'site'},
         )
 
         for test_config in test_configs:
+            self.assertRaises(config_options.ValidationError,
+                              self.validate_config, test_config)
 
-            docs_dir = config_options.Dir()
-            option = config_options.SiteDir()
+    def test_common_prefix(self):
+        """ Legitimate settings with common prefixes should not fail validation. """
 
-            test_config['docs_dir'] = docs_dir.validate(test_config['docs_dir'])
-            test_config['site_dir'] = option.validate(test_config['site_dir'])
+        test_configs = (
+            {'docs_dir': 'docs', 'site_dir': 'docs-site'},
+            {'docs_dir': 'site-docs', 'site_dir': 'site'},
+        )
 
-            option.post_validation(test_config, 'key')
-            self.assertEqual(len(option.warnings), 1)
-            self.assertEqual(
-                option.warnings[0][:50],
-                "The 'site_dir' should not be within the 'docs_dir'")
+        for test_config in test_configs:
+            assert self.validate_config(test_config)
 
 
 class ThemeTest(unittest.TestCase):
@@ -252,7 +299,7 @@ class ExtrasTest(unittest.TestCase):
         self.assertRaises(config_options.ValidationError,
                           option.validate, {})
 
-    def test_talk(self):
+    def test_walk(self):
 
         option = config_options.Extras(utils.is_markdown_file)
 
